#!/bin/sh

# Purpose: 
#	1. Detect X server version
#	2. Detect system architecture
# Description: 
#	1. The script tries to detect version of X (it has to detect XFree86 4.1.X, 4.2.X, 4.3.X and XOrg 6.8.X on most of 
# 	installations).  The detected version (or diagnostics) is printed out.  Also, variable X_VERSION is set to a string
#	having the following format: "XFree86|XOrg <major>.<minor>.<x>" (or empty string, if cannot detect X version)
#	2. The script runs 'uname -m" to detect the architechture, prints it out and sets variable _ARCH to the value 
#	returned by uname
# Known users: 
#	- end user
# 	- ati-installer.sh

DetectX()
{
    x_bin=/usr/X11R6/bin/X
    
    if [ -x ${x_bin} ];
    then
	# First, try to detect XFree86
	x_ver_num=`${x_bin} -version 2>&1 | grep 'XFree86 Version [0-9]\.' | sed -e 's/^.*XFree86 Version //' | cut -d' ' -f1`
	
	if [ "$x_ver_num" ]
	then
    	    X_VERSION="XFree86"
	    
	    # Correct XFree86 version
	    if [ `echo "$x_ver_num" | grep -c '^4\.0\.99'` -gt 0 ]
    	    then
		x_ver_num="4.1.0"
	    fi
	
	    if [ `echo "$x_ver_num" | grep -c '^4\.2\.99'` -gt 0 ]
    	    then
		x_ver_num="4.3.0"
	    fi
	fi
	
	if [ -z "${X_VERSION}" ]
	then
	    #XFree86 has not been detected, try to detect Xorg
	    x_ver_num=`${x_bin} -version 2>&1 | grep 'X Window System Version [0-9]\.' | sed -e 's/^.*X Window System Version //' | cut -d' ' -f1`

	    if [ "$x_ver_num" ]
	    then
    		X_VERSION="Xorg"

                if [ `echo "$x_ver_num" | grep -c '^6\.8\.99'` -gt 0 ]
                then
                    x_ver_num="6.9.0"
                fi
	    fi
	fi
    fi	

    # Produce the final X version string
    if [ "${X_VERSION}" ]
    then
	X_VERSION="${X_VERSION} ${x_ver_num}"
    fi
}

########################################################################
# Begin of the main script

echo "Detected configuration:"

# Detect system architecture
_ARCH=`uname -m`

case ${_ARCH} in
    i?86)	arch_bits="32-bit";;
    x86_64)	arch_bits="64-bit";;
esac

echo "Architecture: ${_ARCH} (${arch_bits})"

# Try to detect version of X, if X_VERSION is not set explicitly by the user
if [ -z "${X_VERSION}" ]; then
    # Detect X version
    DetectX

    if [ -z "${X_VERSION}" ]; then
        echo "X Server: unable to detect"
    else
        echo "X Server: ${X_VERSION}"

        # Generate internal name for the version of X
        x_ver=`echo ${X_VERSION} | cut -d ' ' -f2`
        x_maj=`echo ${x_ver} | cut -d '.' -f1`
        x_min=`echo ${x_ver} | cut -d '.' -f2`
        x_ver_internal="x${x_maj}${x_min}0"
        X_VERSION=${x_ver_internal}
			
        if [ "${_ARCH}" = "x86_64" ]; then
            X_VERSION=${X_VERSION}_64a
        fi
    fi
else
    # If X_VERSION was set by the user, don't try to detect X, just use user's value
    if [ -x map_xname.sh ]; then
        echo "X Server (OVERRIDEN BY USER): `./map_xname.sh ${X_VERSION}`"
    fi
fi

